#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ANY_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ANY_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/scalar/any.hpp>

#endif
